use crate::{constants, widgets};

static THIRD_PARTIE_FONTS: [(&str, &str, Option<&str>); 2] = [
    (
        "UbuntuMono",
        "https://design.ubuntu.com/font/",
        Some("Dalton Maag (under the Ubuntu font licence)"),
    ),
    (
        "IPAMincho",
        "http://ossipedia.ipa.go.jp/ipafont/",
        Some("Information-technology Promotion Agency, Japan (under IPA licence)"),
    ),
];

static THIRD_PARTIE_LIBS: [(&str, &str, Option<&str>); 6] = [
    (
        "serde",
        "https://github.com/serde-rs/serde",
        Some("(under MIT or APACHE-2.0)"),
    ),
    (
        "serde_json",
        "https://github.com/serde-rs/json",
        Some("(under MIT or APACHE-2.0)"),
    ),
    (
        "egui",
        "https://github.com/emilk/egui",
        Some("(under MIT or APACHE-2.0)"),
    ),
    (
        "lazy_static",
        "https://github.com/rust-lang-nursery/lazy-static.rs",
        Some("(under MIT or APACHE-2.0)"),
    ),
    (
        "regex",
        "https://github.com/rust-lang/regex",
        Some("(under MIT or APACHE-2.0)"),
    ),
    (
        "image",
        "https://github.com/image-rs/image",
        Some("(under MIT)"),
    ),
];

pub fn render_about_window(
    show: &mut bool,
    dark_mode: bool,
    ctx: &egui::Context,
    logo: &egui::TextureHandle,
) {
    widgets::WindowBuilder::new("About", dark_mode)
        .with_resizable(true)
        .show(show, ctx, |ui| {
            {
                ui.separator();
                widgets::add_heading2_label(ui, "☰  Amadeus RS");
                ui.style_mut().override_text_style = Some(crate::utils::font::body());
                ui.horizontal_top(|ui| {
                    ui.image(logo, logo.size_vec2());
                    ui.add_space(constants::PADDING);
                    ui.add(
                        egui::Label::new(concat!(
                            "Amadeus RS is a rewrite of the Amadeus front end to lektord.\n",
                            "Amadeus RS is under the MIT licence."
                        ))
                        .wrap(true),
                    );
                });
                ui.add_space(constants::PADDING);
            }

            {
                ui.separator();
                widgets::add_heading2_label(ui, "☰  Third party libraries and fonts");
                ui.style_mut().override_text_style = Some(crate::utils::font::body());
                ui.label("The followinf thrid party libraries where used:");
                for (label, url, after) in THIRD_PARTIE_LIBS {
                    widgets::add_bullet_hyperlink(ui, label, url, after);
                }
                ui.add_space(constants::PADDING);
                ui.label("The following third party fonts where used:");
                for (label, url, after) in THIRD_PARTIE_FONTS {
                    widgets::add_bullet_hyperlink(ui, label, url, after);
                }
                ui.add_space(constants::PADDING);
            }
        });
}
